@@ -12,7 +12,7 @@
 #' @examples
 #' # add interactive continuous legend guide to a ggplot -------
 #' @example examples/scale_viridis_guide_legend_continuous_interactive.R
-#' @seealso [interactive_parameters()], [girafe()]
+#' @seealso [interactive_parameters], [girafe()]
 #' @export
 guide_legend_interactive <- function(...)
   guide_interactive(guide_legend, "interactive_legend", ...)
@@ -28,3 +28,10 @@ guide_train.interactive_legend <- function(guide,
 
   copy_interactive_attrs_from_scale(zz, scale)
 }
+
+#' @export
+guide_geom.interactive_legend <- function(guide,
+                                         layers,
+                                         default_mapping) {
+  check_guide_key_geoms(NextMethod())
+}
